#!/usr/bin/env python
# -*- coding: utf-8 -*-
provider=[
	{
		"name":"github", 
		"cname":["github.io", "github.map.fastly.net"], 
		"response":["There isn't a GitHub Pages site here.", "For root URLs (like http://example.com/) you must provide an index.html file"]
	},
	{
		"name":"heroku", 
		"cname":["herokudns.com", "herokussl.com", "herokuapp.com"], 
		"response":["There's nothing here, yet.", "herokucdn.com/error-pages/no-such-app.html", "<title>No such app</title>"]
	},
	{
		"name":"unbounce",
		"cname":["unbouncepages.com"],
		"response":["The requested URL / was not found on this server.", "The requested URL was not found on this server"]
	},
	{
		"name":"tumblr",
		"cname":["tumblr.com"],
		"response":["There's nothing here.", "Whatever you were looking for doesn't currently exist at this address."]
	},
	{
		"name":"shopify",
		"cname":["myshopify.com"],
		"response":["Sorry, this shop is currently unavailable.", "Only one step left!"]
	},
	{
		"name":"instapage",
		"cname":["pageserve.co", "secure.pageserve.co", "https://instapage.com/"],
		"response":["You've Discovered A Missing Link. Our Apologies!"]
	},
	{
		"name":"desk",
		"cname":["desk.com"],
		"response":["Please try again or try Desk.com free for 14 days.", "Sorry, We Couldn't Find That Page"]
	},
	{
		"name":"tictail",
		"cname":["tictail.com", "domains.tictail.com"],
		"response":["Building a brand of your own?", "to target URL: <a href=\"https://tictail.com", "Start selling on Tictail."]
	},
	{
		"name":"campaignmonitor",
		"cname":["createsend.com", "name.createsend.com"],
		"response":["Double check the URL", "<strong>Trying to access your account?</strong>"]
	},
	{
		"name":"cargocollective",
		"cname":["cargocollective.com"],
		"response":["404 Not Found"]
	},
	{
		"name":"statuspage",
		"cname":["statuspage.io"],
		"response":["Better Status Communication", "You are being <a href=\"https://www.statuspage.io\">redirected"]
	},
	{
		"name":"amazonaws",
		"cname":["amazonaws.com"],
		"response":["NoSuchBucket", "The specified bucket does not exist"]
	},
	{
		"name":"cloudfront",
		"cname":["cloudfront.net"],
		"response":["The request could not be satisfied", "ERROR: The request could not be satisfied"]
	},
	{
		"name":"bitbucket",
		"cname":["bitbucket.org"],	
		"response":["The page you have requested does not exist"]
	},
	{
		"name":"smartling",
		"cname":["smartling.com"],
		"response":["Domain is not configured"]
	},
	{
		"name":"acquia",
		"cname":["acquia.com"],
		"response":["If you are an Acquia Cloud customer and expect to see your site at this address"]
	},
	{
		"name":"fastly",
		"cname":["fastly.net"],
		"response":["Please check that this domain has been added to a service", "Fastly error: unknown domain"]
	},
	{
		"name":"pantheon",
		"cname":["pantheonsite.io"],
		"response":["The gods are wise", "The gods are wise, but do not know of the site which you seek."]
	},
	{
		"name":"zendesk",
		"cname":["zendesk.com"],
		"response":["<title>Help Center Closed | Zendesk</title>", "Help Center Closed"]
	},
	{
		"name":"uservoice",
		"cname":["uservoice.com"],
		"response":["This UserVoice subdomain is currently available!"]
	},
	{
		"name":"ghost",
		"cname":["ghost.io"],
		"response":["The thing you were looking for is no longer here", "The thing you were looking for is no longer here, or never was"]
	},
	{
		"name":"pingdom",
		"cname":["stats.pingdom.com"],
		"response":["pingdom"]
	},
	{
		"name":"tilda",
		"cname":["tilda.ws"],
		"response":["Domain has been assigned"]
	},
	{
		"name":"wordpress",
		"cname":["wordpress.com"],	
		"response":["Do you want to register"]
	},
	{
		"name":"teamwork",
		"cname":["teamwork.com"],
		"response":["Oops - We didn't find your site."]
	},
	{
		"name":"helpjuice",
		"cname":["helpjuice.com"],
		"response":["We could not find what you're looking for."]
	},
	{
		"name":"helpscout",
		"cname":["helpscoutdocs.com"],
		"response":["No settings were found for this company:"]
	},
	{
		"name":"cargo",
		"cname":["cargocollective.com"],
		"response":["If you're moving your domain away from Cargo you must make this configuration through your registrar's DNS control panel."]
	},
	{
		"name":"feedpress",
		"cname":["redirect.feedpress.me"],
		"response":["The feed has not been found."]
	},
	{
		"name":"surge",
		"cname":["surge.sh"],
		"response":["project not found"]
	},
	{
		"name":"surveygizmo",
		"cname":["privatedomain.sgizmo.com", "privatedomain.surveygizmo.eu", "privatedomain.sgizmoca.com"],
		"response":["data-html-name"]
	},
	{
		"name":"mashery",
		"cname":["mashery.com"],
		"response":["Unrecognized domain <strong>"]
	},
	{
		"name":"intercom",
		"cname":["custom.intercom.help"],
		"response":["This page is reserved for artistic dogs.","<h1 class=\"headline\">Uh oh. That page doesn’t exist.</h1>"]
	},
	{
		"name":"webflow",
		"cname":["proxy.webflow.io"],
		"response":["<p class=\"description\">The page you are looking for doesn't exist or has been moved.</p>"]
	},
	{
		"name":"kajabi",
		"cname":["endpoint.mykajabi.com"],
		"response":["<h1>The page you were looking for doesn't exist.</h1>"]
	},
	{
		"name":"thinkific",
		"cname":["thinkific.com"],
		"response":["You may have mistyped the address or the page may have moved."]
	},
	{
		"name":"tave",
		"cname":["clientaccess.tave.com"],
		"response":["<h1>Error 404: Page Not Found</h1>"]
	},
	{
		"name":"wishpond",
		"cname":["wishpond.com"],
		"response":["https://www.wishpond.com/404?campaign=true"]
	},
	{
		"name":"aftership",
		"cname":["aftership.com"],
		"response":["Oops.</h2><p class=\"text-muted text-tight\">The page you're looking for doesn't exist."]
	},
	{
		"name":"aha",
		"cname":["ideas.aha.io"],
		"response":["There is no portal here ... sending you back to Aha!"]
	},
	{
		"name":"brightcove",
		"cname":["brightcovegallery.com", "gallery.video", "bcvp0rtal.com"],
		"response":["<p class=\"bc-gallery-error-code\">Error Code: 404</p>"]
	},
	{
		"name":"bigcartel",
		"cname":["bigcartel.com"],
		"response":["<h1>Oops! We couldn&#8217;t find that page.</h1>"]
	},
	{
		"name":"activecompaign",
		"cname":["activehosted.com"],
		"response":["alt=\"LIGHTTPD - fly light.\""]
	},
	{
		"name":"compaignmonitor",
		"cname":["createsend.com"],
		"response":["Double check the URL or <a href=\"mailto:help@createsend.com"]
	},
	{
		"name":"acquia",
		"cname":["acquia-test.co"],
		"response":["The site you are looking for could not be found."]
	},
	{
		"name":"proposify",
		"cname":["proposify.biz"],
		"response":["If you need immediate assistance, please contact <a href=\"mailto:support@proposify.biz"]
	},
	{
		"name":"simplebooklet",
		"cname":["simplebooklet.com"],
		"response":["We can't find this <a href=\"https://simplebooklet.com"]
	},
	{
		"name":"getresponse",
		"cname":[".gr8.com"],
		"response":["With GetResponse Landing Pages, lead generation has never been easier"]
	},
	{
		"name":"vend",
		"cname":["vendecommerce.com"],
		"response":["Looks like you've traveled too far into cyberspace."]
	},
	{
		"name":"jetbrains",
		"cname":["myjetbrains.com"],
		"response":["is not a registered InCloud YouTrack."]
	},
	{
		"name":"azure",
		"cname":["azurewebsites.net"],
		"response":["404 Web Site not found"]
	}
]



fb_access_token='EAAMBsm9y4NABAC16qhlZAGUGnTh86E83wK8N7LTGzmYZAtgZAl5rQrVwE1GyuvytIoQHwZBoKs2SW0k91DC4R8xiLU3lBE0XIeahQnAZAO5ZAPI3gfrrgVVyCZBubH6jL6AsZBzq0mhFD388IqcatpZBIyFZCx8ZBWpmqM44sqJJficXqnNZA5G3msZAEYiLLPGCwdQMZD'


#!/usr/bin/env python
# -*- coding: utf-8 -*-
import setuptools,os

with open("README.md", "r") as fh:
    long_description = fh.read()
thelibFolder = os.path.dirname(os.path.realpath(__file__))
requirementPath = thelibFolder + '/requirements.txt'
install_requires = [] # Examples: ["gunicorn", "docutils>=0.3", "lxml==0.5a7"]
if os.path.isfile(requirementPath):
    with open(requirementPath) as f:
        install_requires = f.read().splitlines()
setuptools.setup(
    name="kickdomain",
    version="1.3.0",
    author="Syed Abuthahir",
    author_email="developerabu@gmail.com",
    description="Subdomain takeover tool",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/abuvanth/kickdomain",
    packages=['kickdomain','kickdomain.provider'],
    install_requires=install_requires,
    scripts=['kickdomain/kickdomain.py'],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)
